test
open | / |
echo | test |
assertNotBodyText | test |
verifyNotBodyText | test |
assertLocation | http://localhost:8080/Autobot/ |
verifyLocation | http://localhost:8080/Autobot/ |
assertNotLocation | http://localhost:8080 |
verifyNotLocation | http://localhost:8080 |
assertElementNotPresent | id=test |
verifyElementNotPresent | //xxx |
assertElementPresent | id=customerId |
verifyElementPresent | //input[@id="customerId"] |
assertAttribute | id=customerId@aria-required | true
verifyAttribute | id=customerId@aria-required | true
assertNotAttribute | id=customerId@aria-required | false
verifyNotAttribute | id=customerId@aria-required | false
assertText | id=customerId |
verifyText | id=customerId |
assertNotText | id=customerId | test
verifyNotText | id=customerId | test
assertTitle |  |
verifyTitle |  |
assertNotTitle | test |
verifyNotTitle | test |
assertVisible | id=customerId |
verifyVisible | id=customerId |
assertXpathCount | //div[@role="button"] | 9
verifyXpathCount | //div[@role="button"] | 9
assertNotXpathCount | //div[@role="button"] | 8
verifyNotXpathCount | //div[@role="button"] | 8
chooseCancelOnNextConfirmation |  |
chooseOkOnNextConfirmation |  |
chooseOkOnNextConfirmationAndWait |  |
assertAlertNotPresent |  |
verifyAlertNotPresent |  |
assertNotAlert | test |
verifyNotAlert | test |
assertConfirmationNotPresent |  |
verifyConfirmationNotPresent |  |
assertNotConfirmation | test |
verifyNotConfirmation | test |
assertNotChecked | id=customerId |
verifyNotChecked | id=customerId |
assertNotValue | id=customerId |
verifyNotValue | id=customerId |
waitForNotBodyText | test |
waitForConfirmationNotPresent |  |
waitForAttribute | id=customerId@aria-required | true
waitForNotAttribute | id=customerId@aria-required | false
waitForElementPresent | id=customerId |
waitForElementNotPresent | id=customer |
waitForLocation | http://localhost:8080/Autobot/ |
waitForNotLocation | http://localhost:8080 |
waitForNotChecked | id=customerId |
waitForText | id=customerId |
waitForNotText | id=customerId | test
waitForTitle |  |
waitForNotTitle | test |
waitForVisible | id=customerId |
waitForXpathCount | //div[@role="button"] | 9
waitForNotXpathCount | //div[@role="button"] | 8
pause | 2000 |
refresh |  |
refreshAndWait |  |
goBack |  |
goBackAndWait |  |
check | id=customerId |
checkAndWait | id=customerId |
uncheck | id=customerId |
uncheckAndWait | id=customerId |
sendKeys | id=customerName | Charlie
sendKeysAndWait | id=customerBirthNo | 700101/0001
type | id=customerRegNo | 12345
typeAndWait | id=customerTaxNo | CZ12345
select | //div[@id="customerStatus"]/select | active
selectAndWait | //div[@id="customerSegment"]/select | RES
click | id=customerCreate |
clickAndWait | id=customerRead |
submit | id=customerRead |
submitAndWait | id=customerRead |
store | test | test
storeAttribute | id=customerId@aria-required | attr
storeBodyText | body |
storeChecked | id=customerId | check
storeLocation | location |
storeTitle | title |
storeValue | id=customerId | val
storeVisible | id=customerId | visible
storeElementPresent | id=customerId | present
storeText | id=customerId | text
storeXpathCount | //div[@role="button"] | xpath
close |  |